@@ -4,6 +4,10 @@
  * @private
  */
 
+/**
+ * @typedef { import("../../types/index.esm").ChartOptions } ChartOptions
+ */
+
 /**
  * @return {*}
  */
@@ -30,6 +34,13 @@ export class DateAdapter {
     this.options = options || {};
   }
 
+  /**
+   * Will called with chart options after adapter creation.
+   * @param {ChartOptions} chartOptions
+   */
+  // eslint-disable-next-line no-unused-vars
+  init(chartOptions) {}
+
   /**
 	 * Returns a map of time formats for the supported formatting units defined
 	 * in Unit as well as 'datetime' representing a detailed date/time string.
